@@ -998,8 +998,6 @@ sub PackageWithConstructor {
 	my $objectParameters = $class->ObjectParameters();
 	if($objectParameters) {
 		$packageWithConstructor .= $objectParameters;
-	} else {
-		return 1;
 	}
 
 	$currentToken = $class->getToken();
@@ -1099,8 +1097,6 @@ sub PackageWithConstructor {
 	my $qw = $class->QW();
 	if($qw) {
 		$packageWithConstructor .= $qw;
-	} else {
-		return 1;
 	}
 
 	return $packageWithConstructor;
@@ -1366,6 +1362,611 @@ sub CodeBlock {
 	return $codeBlock;
 }
 
+sub Blocks {
+	my ($class) = @_;
+	my $blocks = "";
+
+	my $block = $class->Block();
+	if($block) {
+		$blocks .= $block;
+	} else {
+		return $blocks;
+	}
+
+	my $rightBlock = $class->Blocks();
+	if($rightBlock) {
+		$blocks .= $rightBlock;
+	} else {
+		return 0;
+	}
+
+	return $blocks;
+}
+
+sub Block {
+	my ($class) = @_;
+	my $block = "";
+
+	my $ifElse = $class->IfElse();
+	if($ifElse) {
+		return $ifElse;
+	}
+
+	my $ifWhile = $class->While();
+	if($ifWhile) {
+		return $ifWhile;
+	}
+
+	my $forEach = $class->ForEach();
+	if($forEach) {
+		return $forEach;
+	}
+
+	my $for = $class->For();
+	if($for) {
+		return $for;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	my $comment = $class->Comment();
+	if($comment) {
+		return $comment;
+	}
+
+	my $statement = $class->Statement();
+	if($statement) {
+		return $statement;
+	}
+
+	return 0;
+}
+
+sub EmbedBlock {
+	my ($class) = @_;
+	my $embedBlock = "";
+
+	my $tokenEmbedBlock = $class->TokenEmbedBlock();
+	if($tokenEmbedBlock) {
+		$embedBlock .= $tokenEmbedBlock;
+	} else {
+		return 0;
+	}
+
+	my $embedCodeBlock = $class->EmbedCodeBlock();
+	if($embedCodeBlock) {
+		$embedBlock .= $embedCodeBlock;
+	} else {
+		return 0;
+	}
+
+	return $embedBlock;
+}
+
+sub EmbedCodeBlock {
+	my ($class) = @_;
+	my $embedCodeBlock = "";
+
+	my $embedBegin = $class->EmbedBegin();
+	if($embedBegin) {
+		$embedCodeBlock .= $embedBegin;
+	} else {
+		return 0;
+	}
+
+	my $embeddedCode = $class->EmbeddedCode();
+	if($embeddedCode) {
+		$embedCodeBlock .= $embeddedCode;
+	} else {
+		return 0;
+	}
+
+	my $embedEnd = $class->EmbedEnd();
+	if($embedEnd) {
+		$embedCodeBlock .= $embedEnd;
+	} else {
+		return 0;
+	}
+
+	return $embedCodeBlock;
+}
+
+sub EmbedBegin {
+	my ($class) = @_;
+	my $embedBegin = "";
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$embedBegin .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq "?") {
+		$embedBegin .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $embedBegin;
+}
+
+sub EmbedEnd {
+	my ($class) = @_;
+	my $embedEnd = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq "?") {
+		$embedEnd .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$embedEnd .= $rParen;
+	} else {
+		return 0;
+	}
+
+	return $embedEnd;
+}
+
+sub EmbeddedCode {
+	my ($class) = @_;
+	my $embeddedCode = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "EmbedBlock") {
+		$embedEnd .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $embedEnd;
+}
+
+sub While {
+	my ($class) = @_;
+	my $while = "";
+
+	my $tokenWhile = $class->TokenWhile();
+	if($tokenWhile) {
+		$while .= $tokenWhile;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$while .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $boolExpression = $class->BoolExpression();
+	if($boolExpression) {
+		$while .= $boolExpression;
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$while .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$while .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $while;
+}
+
+sub ForEach {
+	my ($class) = @_;
+	my $forEach = "";
+
+	my $tokenForEach = $class->TokenForEach();
+	if($tokenForEach) {
+		$forEach .= $tokenForEach;
+	} else {
+		return 0;
+	}
+
+	my $var = $class->Var();
+	if($var) {
+		$forEach .= $var;
+	} else {
+		return 0;
+	}
+
+	my $forEachVariableName = $class->ForEachVariableName();
+	if($forEachVariableName) {
+		$forEach .= $forEachVariableName;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$forEach .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$forEach .= $variableName;
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$forEach .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$forEach .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $codeBlock;
+}
+
+
+sub ForEachVariableName {
+	my ($class) = @_;
+	my $forEachVariableName = "";
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$forEachVariableName .= $variableName;
+	} else {
+		return 0;
+	}
+
+	return $forEachVariableName;
+}
+
+sub For {
+	my ($class) = @_;
+	my $for = "";
+
+	my $tokenFor = $class->TokenFor();
+	if($tokenFor) {
+		$for .= $tokenFor;
+	} else {
+		return 0;
+	}
+
+	my $var = $class->Var();
+	if($var) {
+		$for .= $var;
+	} else {
+		return 0;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$for .= $variableName;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$for .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $forRange = $class->ForRange();
+	if($forRange) {
+		$for .= $forRange;
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$for .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$for .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $codeBlock;
+}
+
+sub ForRange {
+	my ($class) = @_;
+	my $forRange = "";
+
+	my $lowerRange = $class->LowerRange();
+	if($lowerRange) {
+		$forRange .= $lowerRange;
+	} else {
+		return 0;
+	}
+
+	my $dot = $class->Dot();
+	if($dot) {
+		$forRange .= $dot;
+	} else {
+		return 0;
+	}
+
+	my $dot = $class->Dot();
+	if($dot) {
+		$forRange .= $dot;
+	} else {
+		return 0;
+	}
+
+	my $dot = $class->Dot();
+	if($dot) {
+		$forRange .= $dot;
+	} else {
+		return 0;
+	}
+
+	my $upperRange = $class->UpperRange();
+	if($upperRange) {
+		$forRange .= $upperRange;
+	} else {
+		return 0;
+	}
+
+	return $forRange;
+}
+
+sub LowerRange {
+	my ($class) = @_;
+
+	my $number = $class->Number();
+	if($number) {
+		return $number;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $classAccessor = $class->ClassAccessor();
+	if($classAccessor) {
+		return $classAccessor;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $FunctionReturn = $class->FunctionReturn();
+	if($FunctionReturn) {
+		return $FunctionReturn;
+	}
+
+	return 0;
+}
+
+sub UpperRange {
+	my ($class) = @_;
+
+	my $number = $class->Number();
+	if($number) {
+		return $number;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $classAccessor = $class->ClassAccessor();
+	if($classAccessor) {
+		return $classAccessor;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $FunctionReturn = $class->FunctionReturn();
+	if($FunctionReturn) {
+		return $FunctionReturn;
+	}
+
+	return 0;
+}
+
+
+sub IfElse {
+	my ($class) = @_;
+	my $ifElse = "";
+
+	my $if = $class->If();
+	if($if) {
+		$ifElse .= $if;
+	} else {
+		return 0;
+	}
+
+	my $elsIf = $class->ElsIf();
+	if($elsIf) {
+		$ifElse .= $elsIf;
+	}
+
+	my $else = $class->Else();
+	if($else) {
+		$ifElse .= $else;
+	}
+
+	return $ifElse;
+}
+
+sub If {
+	my ($class) = @_;
+	my $if = "";
+
+	my $tokenIf = $class->TokenIf();
+	if($tokenIf) {
+		$if .= $tokenIf;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$if .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $boolExpression = $class->BoolExpression();
+	if($boolExpression) {
+		$if .= $boolExpression;
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$if .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$if .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $if;
+}
+
+sub BoolExpression {
+	my ($class) = @_;
+	my $boolExpression = "";
+
+	my $booleanExpression = $class->BooleanExpression();
+	if($booleanExpression) {
+		$boolExpression .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	my $booleanOperator = $class->BooleanOperator();
+	if($booleanOperator) {
+		$boolExpression .= $booleanOperator;
+	} else {
+		return $boolExpression;
+	}
+
+	my $rightBooleanExpression = $class->BoolExpression();
+	if($rightBooleanExpression) {
+		$boolExpression .= $rightBooleanExpression;
+	} else {
+		return 0;
+	}
+
+	return $boolExpression;
+}
+
+sub BooleanExpression {
+	my ($class) = @_;
+	my $booleanExpression = "";
+
+	my $boolOperands = $class->BoolOperands();
+	if($boolOperands) {
+		$booleanExpression .= $boolOperands;
+	} else {
+		return 0;
+	}
+
+	my $boolOperatorExpression = $class->BoolOperatorExpression();
+	if($boolOperatorExpression) {
+		$booleanExpression .= $boolOperatorExpression;
+	}
+
+	return $booleanExpression;
+}
+
+sub BoolOperatorExpression {
+	my ($class) = @_;
+	my $boolOperatorExpression = "";
+
+	my $boolOperator = $class->BoolOperator();
+	if($boolOperator) {
+		$boolOperatorExpression .= $boolOperator;
+	} else {
+		return 0;
+	}
+
+	my $boolOperands = $class->BoolOperands();
+	if($boolOperands) {
+		$boolOperatorExpression .= $boolOperands;
+	} else {
+		return 0;
+	}
+
+	return $boolOperatorExpression;
+}
+
+sub BoolOperands {
+	my ($class) = @_;
+
+	my $realNumber = $class->RealNumber();
+	if($realNumber) {
+
+	}
+}
+
 
 1;
 
@@ -1375,7 +1976,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     my ($class) = @_;
@@ -1404,6 +2005,10 @@ Lang::HL::Syntax - Syntax Check for HL
 
 	$> hle <directory>
 
+=head1 DESCRIPTION
+
+An another compiler for HL. A work in progress.
+
 =head1 AUTHOR
 
 Rajkumar Reddy
